---@diagnostic disable: undefined-global
function HUDChat.seconds_to_time_string(input_seconds)

    local function get_spacing_zero(number)
        if (number / 10) < 1 then
            return "0"
        end
        return ""
    end

    if not input_seconds or type(input_seconds) ~= "number" then
        return ""
    end 
    local seconds = math.floor( input_seconds % 60 )
    local minutes = math.floor( input_seconds / 60 )

    return get_spacing_zero(minutes) .. tostring( minutes ) .. ":" .. get_spacing_zero(seconds) .. tostring(seconds)
end

function HUDChat:receive_message(name, message, color, icon)
	local output_panel = self._panel:child("output_panel")
	local name_len = utf8.len(name) + 1
    local timestamp = nil
    local ts_len
    if CTS.properties.mod_enabled and managers.hud._hud_heist_timer and managers.hud._hud_heist_timer._last_time then
        timestamp = "[" .. self.seconds_to_time_string( tonumber(managers.hud._hud_heist_timer._last_time) ) .. "] "
        ts_len = utf8.len(timestamp) 
    end
	local x = 0
	local icon_bitmap = nil

	if icon then
		local icon_texture, icon_texture_rect = tweak_data.hud_icons:get_icon_data(icon)
		icon_bitmap = output_panel:bitmap({
			y = 1,
			texture = icon_texture,
			texture_rect = icon_texture_rect,
			color = color
		})
		x = icon_bitmap:right()
	end
    

	local line = output_panel:text({
		halign = "left",
		vertical = "top",
		hvertical = "top",
		wrap = true,
		align = "left",
		blend_mode = "normal",
		word_wrap = true,
		y = 0,
		layer = 0,
		text = (timestamp or "") .. name .. ": " .. message,
		font = tweak_data.menu.pd2_small_font,
		font_size = tweak_data.menu.pd2_small_font_size,
		x = x,
		color = color
	})
	local total_len = utf8.len(line:text())

    if timestamp and timestamp ~= "" then
        line:set_range_color(0, ts_len, CTS and Color( CTS.properties.red_part / 100, CTS.properties.green_part / 100, CTS.properties.blue_part / 100 ) or Color(1,0.5,0.7)) 
        line:set_range_color(ts_len, ts_len + name_len, color)
	    line:set_range_color(ts_len + name_len, total_len, Color.white)
    else
        line:set_range_color(0, name_len, color)
        line:set_range_color(name_len, total_len, Color.white)
    end

	local _, _, w, h = line:text_rect()

	line:set_h(h)
	table.insert(self._lines, {
		line,
		icon_bitmap
	})
	line:set_kern(line:kern())
	self:_layout_output_panel()

	if not self._focus then
		local output_panel = self._panel:child("output_panel")

		output_panel:stop()
		output_panel:animate(callback(self, self, "_animate_show_component"), output_panel:alpha())
		output_panel:animate(callback(self, self, "_animate_fade_output"))
	end
end
